@@ -2,14 +2,14 @@ package EZDBI;
 use DBI;
 use strict;
 use Carp;
-use vars qw'$E @EXPORT @EXPORT_OK $VERSION $MAX_STH $BINDABLE';
+use vars qw'$E @EXPORT @EXPORT_OK $VERSION $MAX_STH $BINDABLE $DEBUG';
 require 5;
 
 my $DBH;
 *E = \$DBI::errstr;
 my $sth_cache;   # string to statement handle cache
 my $sth_cacheA;  # oldest first (LRU)  handle order
-$VERSION = 0.14;
+$VERSION = 0.16;
 
 # Note that this package does NOT inherit from Exporter
 @EXPORT = qw(Connect Delete Disconnect Insert Select Sql Update Use);
@@ -170,8 +170,8 @@ sub Update {
     unless($str =~ /\bset\b\s*$/i){
       $str .= ' Set'
     }
-    $str .= ' ' . join(', ', map{"$_=?"}@cols) .
-      (defined($args[1]) ? shift @args : '');
+    $str .= join(',', map{" $_=?"} @cols);
+    $str .= defined($args[0]) ? ' ' . shift @args : '';
     @args = (@hash{@cols}, @args);
   }
 
@@ -195,7 +195,7 @@ sub _parseIni{
   my $self;
   open(my $INI, $parm{'-file'}) || croak("$!: $parm{-file}\n");
   while( <$INI> ){
-    next if /^\s*$|(?:[\#\;])/;
+    next if /^\s*(?:$|[\#\;])/;
     if( /^\s*\[$parm{'-label'}\]/ ..
 	(/^\s*\[(?!$parm{'-label'})/ || eof($INI) ) ){
       /^\s*([^=]+?)\s*=\s*(.*)$/;
@@ -232,6 +232,8 @@ sub _substitute {
     }
   }
 
+  carp "$function $str" if $DEBUG;
+
   my $subct = $str =~ tr/?/?/;
   if( $subct > $Nargs ){
     croak "Not enough arguments for $function ($subct required)";
@@ -257,7 +259,7 @@ sub _substitute {
     # prepare new handle
     $sth = $DBH->prepare("$function $str");
     croak "Couldn't prepare query for '$function $str': $E; aborting" unless $sth;
-    #XXX BINDING
+    #BINDING
     foreach(my $i=0; $BINDABLE && $i<$Nargs; $i++){
       if( ref($args->[$i]) eq 'ARRAY' ){
 	$sth->bind_param($i+1, undef, $args->[$i]->[1]);
@@ -344,6 +346,15 @@ difficult to document because every database is a little different. Typically,
 you supply a username and a password here if the database requires them.
 Consult the documentation of your B<DBD> for more information.
 
+=cut
+
+You may also pass additional arguments to DBI via a hash reference
+after the other parameters e.g;
+
+    Connect 'type:database', ..., {LongReadLen=>2**13};
+
+=pod
+
 The second way to connect to a database is especially useful if you maintain
 many scripts that use the same connection information, it allows you store
 your connection parameters in an B<AppConfig> (Windows INI) format file,
@@ -381,22 +392,24 @@ take precedence over those set in the resource file.
 =back
 
 Here is an example resource file.
-
   [section]
   user     = Bob
   pass     = Smith
   dsn      = dbi:mysql:?
   attr Foo = Bar
 
+B<Note that section names, properties and values are all I<case-sensitive>>.
+
 =over
 
 =item I<user>
 
-Required. The username to connect with.
+The username to connect with.
 
 =item I<pass>
 
-Required. The password to connect with, be sure to protect you resource file.
+The password to connect with, be sure to protect your resource file e.g;
+C<chmod go-rw> to prevent others from reading it.
 
 =item I<dsn>
 
@@ -585,7 +598,7 @@ by B<EZDBI> such as C<Grant>.
 
   Sql('Drop FOO');
 
-NOTE: Sql does not return a recirdest, as it is implemented with C<DBI::do()>.
+NOTE: Sql does not return a recordest, as it is implemented with C<DBI::do()>.
 As such C<Sql> is not especially useful for commands like MySQL's I<Describe>.
 
 =head2 C<Use>
@@ -608,8 +621,8 @@ allows you to do this more efficiently.
   Select('plugh From FOO.BARFLE');
   Select('xyzzy From BAR.ZAZ');
 
-Rather this is most appropriate when connections to databases on seperate
-machines need to be maintained.
+Rather this is most appropriate when connections to different database
+servers are required.
 
 =head2 Binding
 
@@ -626,12 +639,15 @@ you wish to be bound/cast as tuples like so:
 Note: It is senseless to change the binding type of a column between
 invocations, and doing so may be hazardous to your health.
 
-=head1 ERRORS
+=head1 DEBUGGING / ERRORS
 
 If there's an error, B<EZDBI> prints a (hopefully explanatory) message
 and throws an exception. You can catch the exception with C<eval { ... }>,
 or let it kill your program.
 
+Set I<$EZDBI::DEBUG> to a true value to display the actual SQL statements
+EZDBI is passing to L<DBI>.
+
 =head1 ENVIRONMENT
 
 =over
